@@ -1,13 +1,14 @@
 timeline1 <- 'box(
   title = "Reversed Timeline: ideal to include in a box",
   status = "info",
-  width = NULL,
+  width = 12,
   timelineBlock(
-    timelineEnd(color = "danger"),
+    width = 12,
+    timelineEnd(color = "red"),
     timelineLabel(2018, color = "teal"),
     timelineItem(
       title = "Item 1",
-      icon = "gears",
+      icon = icon("gears"),
       color = "olive",
       time = "now",
       footer = "Here is the footer",
@@ -20,23 +21,24 @@ timeline1 <- 'box(
     timelineLabel(2015, color = "orange"),
     timelineItem(
       title = "Item 3",
-      icon = "paint-brush",
+      icon = icon("paint-brush"),
       color = "maroon",
-      timelineItemMedia(src = "https://placehold.it/150x100"),
-      timelineItemMedia(src = "https://placehold.it/150x100")
+      timelineItemMedia(image = "https://placehold.it/150x100"),
+      timelineItemMedia(image = "https://placehold.it/150x100")
     ),
-    timelineStart(color = "gray")
+    timelineStart(color = "purple")
   )
 )'
 
 
 timeline2 <- 'timelineBlock(
   reversed = FALSE,
-  timelineEnd(color = "danger"),
+  width = 12,
+  timelineEnd(color = "red"),
   timelineLabel(2018, color = "teal"),
   timelineItem(
     title = "Item 1",
-    icon = "gears",
+    icon = icon("gears"),
     color = "olive",
     time = "now",
     footer = "Here is the footer",
@@ -49,10 +51,10 @@ timeline2 <- 'timelineBlock(
   timelineLabel(2015, color = "orange"),
   timelineItem(
     title = "Item 3",
-    icon = "paint-brush",
+    icon = icon("paint-brush"),
     color = "maroon",
-    timelineItemMedia(src = "https://placehold.it/150x100"),
-    timelineItemMedia(src = "https://placehold.it/150x100")
+    timelineItemMedia(image = "https://placehold.it/150x100"),
+    timelineItemMedia(image = "https://placehold.it/150x100")
   ),
-  timelineStart(color = "gray")
+  timelineStart(color = "purple")
 )'
\ No newline at end of file
